SELECT 10/mysqlclient - Criterion.rs

## SELECT 10/mysqlclient

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0012787 | 0.0013250 | 0.0012726
Mean | 7.2861 ms | 7.4409 ms | 7.6060 ms
Std. Dev. | 652.32 µs | 816.88 µs | 961.68 µs
Median | 6.9437 ms | 7.1155 ms | 7.2650 ms
MAD | 272.53 µs | 471.02 µs | 683.83 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.